==> hledger-1.14.2-46-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger
version: 1.14.2
id: hledger-1.14.2-Gz7cJNodWf9LdqyHsmLdpc
key: hledger-1.14.2-Gz7cJNodWf9LdqyHsmLdpc
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance, Console
abi: 04221cb27fb70385deeecd425a4b29ac
exposed: True
exposed-modules:
    Hledger.Cli Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Close
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Files
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Roi
    Hledger.Cli.Commands.Stats Hledger.Cli.Commands.Tags
    Hledger.Cli.CompoundBalanceCommand Hledger.Cli.DocFiles
    Hledger.Cli.Main Hledger.Cli.Utils Hledger.Cli.Version
hidden-modules: Paths_hledger
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger
hs-libraries: HShledger-1.14.2-Gz7cJNodWf9LdqyHsmLdpc
depends:
    Decimal-0.5.1-H2kU9PQoNIhDDGeZUlyXId
    Diff-0.3.4-C6Bl1un4oiiBWGaHLlh5bu
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X base-4.12.0.0
    base-compat-batteries-0.10.5-KvYjlXLhf5S8nu3CG2PCKk
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 data-default-0.7.1.1-FxanJFkeYAJQ1iDuwiDPz
    directory-1.3.3.0 easytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
    filepath-1.4.2.1 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskeline-0.7.4.3 hledger-lib-1.14.1-HtVoy6GU1TODEC5ltPR4KG
    lucid-2.9.11-JLNusYKhD7LImCEBVlhsi7
    math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
    megaparsec-7.0.5-7nNPtHGYzPNBh8epow1r1w mtl-2.2.2
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 process-1.6.5.0
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.20-Cful4WDaZNYHiOOgCEfuhl
    split-0.2.3.3-IbK4kxLa0sUBqxIH6ONm60
    tabular-0.2.2.7-FYVnBEx3xwsDpJzPJOu9nb
    temporary-1.3-DtA9I5S66596vhEnbtLJ0Y terminfo-0.4.1.2 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
    wizards-1.0.3-LeWouXF9w2V7cw8M1LVGLS
haddock-interfaces: /usr/share/doc/hledger/html/hledger.haddock
haddock-html: /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-1.14.2-47-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger
version: 1.14.2
id: hledger-1.14.2-CdnUTRJ8ub6AShrtGkctyJ
key: hledger-1.14.2-CdnUTRJ8ub6AShrtGkctyJ
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance, Console
abi: 8af1f07c721bdbf06f37432bf8376c1b
exposed: True
exposed-modules:
    Hledger.Cli Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Close
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Files
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Roi
    Hledger.Cli.Commands.Stats Hledger.Cli.Commands.Tags
    Hledger.Cli.CompoundBalanceCommand Hledger.Cli.DocFiles
    Hledger.Cli.Main Hledger.Cli.Utils Hledger.Cli.Version
hidden-modules: Paths_hledger
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger
hs-libraries: HShledger-1.14.2-CdnUTRJ8ub6AShrtGkctyJ
depends:
    Decimal-0.5.1-H2kU9PQoNIhDDGeZUlyXId
    Diff-0.3.4-C6Bl1un4oiiBWGaHLlh5bu
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X base-4.12.0.0
    base-compat-batteries-0.10.5-KvYjlXLhf5S8nu3CG2PCKk
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 data-default-0.7.1.1-FxanJFkeYAJQ1iDuwiDPz
    directory-1.3.3.0 easytest-0.2.1-Fvr3pELpRTdDli5viSGCl3
    filepath-1.4.2.1 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskeline-0.7.4.3 hledger-lib-1.14.1-EToCLbsW299JEHerEr5SnW
    lucid-2.9.11-JLNusYKhD7LImCEBVlhsi7
    math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
    megaparsec-7.0.5-7nNPtHGYzPNBh8epow1r1w mtl-2.2.2
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 process-1.6.5.0
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.20-Cful4WDaZNYHiOOgCEfuhl
    split-0.2.3.3-IbK4kxLa0sUBqxIH6ONm60
    tabular-0.2.2.7-FYVnBEx3xwsDpJzPJOu9nb
    temporary-1.3-DtA9I5S66596vhEnbtLJ0Y terminfo-0.4.1.2 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
    wizards-1.0.3-LeWouXF9w2V7cw8M1LVGLS
haddock-interfaces: /usr/share/doc/hledger/html/hledger.haddock
haddock-html: /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
